@@ -1,11 +1,13 @@
-import sys
-import pymysql
 import os
+import sys
+
+import pymysql
 from dotenv import load_dotenv
+
 load_dotenv()
 
 
-class Component():
+class Component:
     @staticmethod
     def get_connection() -> pymysql.connections.Connection:
         return pymysql.connect(
@@ -20,9 +22,9 @@ class Component():
             connection = Component.get_connection()
             cursor = connection.cursor()
             sql_query = "SELECT name, component_type, component_category, testing_framework, api_type FROM component.component_view WHERE component_id = %s"
-            cursor.execute(sql_query, (component_id))
+            cursor.execute(sql_query, (component_id, ))
             result = cursor.fetchone()
             return result
         except Exception as e:
-            print("Exception catched " + str(e), file=sys.stderr)
+            print("Exception caught " + str(e), file=sys.stderr)
             return None
