@@ -1,7 +1,7 @@
 from enum import Enum
 
 
-class LoggerComponentEnum():
+class LoggerComponentEnum:
     class ComponentType(Enum):
         Service = "Service"
         API = "API"
