@@ -1,15 +1,15 @@
-import os
 from functools import wraps
+
 from .Logger import Logger
 
-@staticmethod
+
 def log_function_execution(func):
     @wraps(func)
     def wrapper(*args, **kwargs):
-        logger_local=Logger.create_logger(**kwargs)
+        logger_local = Logger.create_logger(**kwargs)
         object1 = {
             'args': str(args),
-            'kawargs': str(kwargs),
+            'kwargs': str(kwargs),
         }
         logger_local.start(object=object1)
         result = func(*args, **kwargs)  # Execute the function
@@ -18,4 +18,5 @@ def log_function_execution(func):
         }
         logger_local.end(object=object2)
         return result
-    return wrapper
\ No newline at end of file
+
+    return wrapper
