@@ -1,22 +1,24 @@
 import json
 import os
-import sys
+
 from dotenv import load_dotenv
-from .MessageSeverity import MessageSeverity
+
 from .LoggerOutputEnum import LoggerOutputEnum
+from .MessageSeverity import MessageSeverity
 
 load_dotenv()
 
 # TODO If there is no .logger.json file, please write to the console in which directory we should create it.
 # TODO If there is .logger.json file (we support only one right?) , please write to the console the configuration.
-# TODO Can we use SeverityLevelName instead of ServerityLevelId in the .logger.json? - Please add .logger.json.examples
+# TODO Can we use SeverityLevelName instead of SeverityLevelId in the .logger.json? - Please add .logger.json.examples
 # TODO Can we add the component name in addition to the component id in the .logger.json? - Please add .logger.json.examples
 # TODO Can we add comments to the .logger.json file?
 
+DEFAULT_MIN_SEVERITY = 600
 LOGGER_CONFIGURATION_JSON = '.logger.json'
-LOGGER_MINIMUM_SEVERITY = os.getenv('LOGGER_MINIMUM_SEVERITY')
+LOGGER_MINIMUM_SEVERITY = int(os.getenv('LOGGER_MINIMUM_SEVERITY', DEFAULT_MIN_SEVERITY))
 DEBUG_EVERYTHING = False
-LOGGER_JSON = None
+LOGGER_JSON = {}
 
 
 class DebugMode:
@@ -26,10 +28,10 @@ class DebugMode:
         global LOGGER_JSON
         global DEBUG_EVERYTHING
 
-        if LOGGER_MINIMUM_SEVERITY == None:
-            # TODO: Should move the Magic Number to const
-            LOGGER_MINIMUM_SEVERITY = 600 # Minimal Servirity in case there is not LOGGER_MINIMUM_SEVERITY environment variable
-            print ("Using LOGGER_MINIMUM_SEVERITY="+str(LOGGER_MINIMUM_SEVERITY)+" from Logger default (can be overriten by LOGGER_MINIMUM_SEVERITY environment variable or .logger.json file per component and logger output")
+        if LOGGER_MINIMUM_SEVERITY is None:  # Minimal severity in case there is not LOGGER_MINIMUM_SEVERITY environment variable
+            LOGGER_MINIMUM_SEVERITY = DEFAULT_MIN_SEVERITY
+            print(f"Using LOGGER_MINIMUM_SEVERITY={LOGGER_MINIMUM_SEVERITY} from Logger default "
+                  "(can be overridden by LOGGER_MINIMUM_SEVERITY environment variable or .logger.json file per component and logger output")
         else:
             LOGGER_MINIMUM_SEVERITY = str(LOGGER_MINIMUM_SEVERITY)
             if hasattr(MessageSeverity, LOGGER_MINIMUM_SEVERITY):
@@ -38,13 +40,14 @@ class DebugMode:
                 LOGGER_MINIMUM_SEVERITY = int(LOGGER_MINIMUM_SEVERITY)
             else:
                 raise Exception("LOGGER_MINIMUM_SEVERITY must be a valid LoggerOutputEnum or a number or None")
-            print ("Using LOGGER_MINIMUM_SEVERITY="+str(LOGGER_MINIMUM_SEVERITY)+" from environment variable. Can be overriten by .logger.json file per component and logger output.")
+            print("Using LOGGER_MINIMUM_SEVERITY=" + str(
+                LOGGER_MINIMUM_SEVERITY) + " from environment variable. Can be overridden by .logger.json file per component and logger output.")
         try:
             with open(LOGGER_CONFIGURATION_JSON, 'r') as file:
                 LOGGER_JSON = json.load(file)
         except FileNotFoundError:
             DEBUG_EVERYTHING = True
-        except Exception as exception:
+        except Exception:
             raise
 
     @staticmethod
@@ -69,5 +72,6 @@ class DebugMode:
         result = True
         return result
 
+
 # Call init() to initialize global variables used in is_logger_output
 DebugMode.init()
